%{H_TEMPLATE}

#ifndef _%{APPNAMEUC}KMDIVIEW_H
#define _%{APPNAMEUC}KMDIVIEW_H

#include <tdeparts/part.h>
#include <tdemdichildview.h>
#include <tdemdichildfrm.h>

/**
 * This class serves as the %{APPNAMELC}tdemdi view.
 *
 * @short main view class
 */
class %{APPNAMELC}tdemdiView : public KMdiChildView 
{
	TQ_OBJECT
  
	public:
		%{APPNAMELC}tdemdiView( TQWidget *parentWidget=0L, const char *name=0L );
		virtual ~%{APPNAMELC}tdemdiView();

		KParts::ReadWritePart *part() { return m_part; }

	private:
		KParts::ReadWritePart *m_part;
};

#endif // _%{APPNAMEUC}KMDIVIEW_H

